let slideIndex = 0;
let timer;
let isMouseOver = false; // New variable to track if the mouse is over the slideshow

function changeSlide(n) {
  clearTimeout(timer);
  slideIndex += n;
  showSlide();
  startAutoChangeSlide();
}

function showSlide() {
  const slides = document.getElementsByClassName("slide");

  slideIndex = (slideIndex + slides.length) % slides.length;

  Array.from(slides).forEach((slide, i) => {
    if (i === slideIndex) {
      slide.classList.add("fade");
    } else {
      slide.classList.remove("fade");
    }
  });

  updateActiveDot();
}

function startAutoChangeSlide() {
  clearTimeout(timer); // Clear any existing timer before setting a new one
  if (!isMouseOver) { // Check if the mouse is not over the slideshow before setting a new timer
    timer = setTimeout(() => {
      slideIndex++;
      showSlide();
      startAutoChangeSlide();
    }, 4000);
  }
}

createDots();
startAutoChangeSlide();

function createDots() {
  const slides = document.getElementsByClassName("slide");
  const dotContainer = document.querySelector(".dot-container");

  Array.from(slides).forEach((_, i) => {
    const dot = document.createElement("span");
    dot.className = "dot";
    dot.addEventListener("click", () => {
      clearTimeout(timer);
      slideIndex = i;
      showSlide();
      startAutoChangeSlide();
    });
    dotContainer.appendChild(dot);
  });

  updateActiveDot(); // Call updateActiveDot() after creating the dots
}

function updateActiveDot() {
  const dots = document.getElementsByClassName("dot");

  Array.from(dots).forEach((dot, i) => {
    if (i === slideIndex) {
      dot.classList.add("active");
    } else {
      dot.classList.remove("active");
    }
  });
}

// Pause and resume slideshow on mouse enter and leave
const slideshowWrapper = document.querySelector(".slideshow-wrapper");
slideshowWrapper.addEventListener("mouseenter", () => {
  isMouseOver = true;
  clearTimeout(timer);
});
slideshowWrapper.addEventListener("mouseleave", () => {
  isMouseOver = false;
  startAutoChangeSlide();
});

// Pause and resume slideshow when the document's visibility changes
document.addEventListener("visibilitychange", () => {
  if (document.hidden) {
    clearTimeout(timer);
  } else {
    startAutoChangeSlide();
  }
});

document.addEventListener("DOMContentLoaded", () => {
  const imageButtons = document.querySelectorAll(".image-button");
  imageButtons.forEach(button => {
    button.addEventListener("click", () => {
      const link = button.getAttribute("data-link");
      window.location.href = link;
    });
  });
});


// Counter -->
document.addEventListener('DOMContentLoaded', () => {
  const counters = document.querySelectorAll('.counter');
  const options = {
    root: null,
    threshold: 0,
    rootMargin: '0px 0px -20% 0px',
  };

  function startCounter(counter) {
    const countElement = counter.querySelector('.count');
    const max = parseInt(counter.getAttribute('data-target'), 10);
    const speed = 1000 / max;
    let current = 0;

    const updateCounter = () => {
      current += 1;
      countElement.textContent = current;

      if (current < max) {
        setTimeout(updateCounter, speed);
      }
    };

    updateCounter();
  }

  const observer = new IntersectionObserver((entries, observer) => {
    entries.forEach((entry) => {
      if (entry.isIntersecting) {
        startCounter(entry.target);
        observer.unobserve(entry.target);
      }
    });
  }, options);

  counters.forEach((counter) => {
    observer.observe(counter);
  });
});

// custom buttons -->
window.addEventListener('DOMContentLoaded', (event) => {
  const buttons = document.querySelectorAll('.custom-button');
  buttons.forEach(button => {
      button.addEventListener('mouseover', function() {
          this.querySelector('.custom-description').style.display = "block";
      });
      button.addEventListener('mouseout', function() {
          this.querySelector('.custom-description').style.display = "none";
      });
  });
});

// make header and nav align -->
// document.addEventListener("DOMContentLoaded", function() {
//   setWidths();

//   window.onresize = function() {
//     setWidths();
//   };
// });

// function setWidths() {
//   var b = document.querySelector('.md-tabs__list');
//   var a = document.querySelector('.md-header__inner.md-grid');

//   if (a && b) {
//     a.style.width = b.offsetWidth + 'px';
//   }
//   else {
//     console.log("'a' or 'b' element is missing from the DOM.");
//   }
// }